==> cve_bot-0.0.6-py3-none-any.whl: cve_bot/migrations/env.py <==
import sys
from logging.config import fileConfig

from alembic import context
from sqlalchemy import engine_from_config, pool

from cve_bot.config import get_config
from cve_bot.models import Base

config = context.config
app_config = get_config()
fileConfig(config.config_file_name)
target_metadata = [Base.metadata]

if not sys._called_from_test:  # noqa: WPS437
    db_url = f"sqlite:///{app_config['db_path']}"
    config.set_main_option("sqlalchemy.url", db_url)


def run_migrations_offline():
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    url = config.get_main_option("sqlalchemy.url")
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online():
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """
    connectable = engine_from_config(
        config.get_section(config.config_ini_section),
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        context.configure(connection=connection, target_metadata=target_metadata)

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()

==> cve_bot-0.0.11-py3-none-any.whl: cve_bot/migrations/env.py <==
import sys
from logging.config import fileConfig

from alembic import context
from sqlalchemy import engine_from_config, pool

from cve_bot.config import get_config
from cve_bot.models import Base

config = context.config
app_config = get_config()
fileConfig(config.config_file_name)
target_metadata = [Base.metadata]

if not getattr(sys, "_called_from_test", False):  # noqa: WPS437
    db_url = f"sqlite:///{app_config['db_path']}"
    config.set_main_option("sqlalchemy.url", db_url)


def run_migrations_offline():
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    url = config.get_main_option("sqlalchemy.url")
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online():
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """
    connectable = engine_from_config(
        config.get_section(config.config_ini_section),
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        context.configure(connection=connection, target_metadata=target_metadata)

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()
